@@ -3,7 +3,7 @@ use super::*;
 pub trait Fold: ListFn {
     fn fold(mut self) -> Self::End {
         loop {
-            match self.state() {
+            match self.next() {
                 ListState::Some(_, next) => self = next,
                 ListState::End(end) => return end,
             }
